@@ -21,6 +21,8 @@ enumerations include:
      - ECDSA Curve Label [*]_
    * - :class:`HIP_ECDSALowCurve <pcapkit.const.hip.ecdsa_low_curve.ECDSALowCurve>`
      - ECDSA_LOW Curve Label [*]_
+   * - :class:`HIP_EdDSACurve <pcapkit.const.hip.eddsa_curve.EdDSACurve>`
+     - EdDSA Curve Label [*]_
    * - :class:`HIP_ESPTransformSuite <pcapkit.const.hip.esp_transform_suite.ESPTransformSuite>`
      - ESP Transform Suite IDs [*]_
    * - :class:`HIP_Group <pcapkit.const.hip.group.Group>`
@@ -51,6 +53,7 @@ enumerations include:
 .. [*] https://www.iana.org/assignments/hip-parameters/hip-parameters.xhtml#hip-parameters-7
 .. [*] https://www.iana.org/assignments/hip-parameters/hip-parameters.xhtml#ecdsa-curve-label
 .. [*] https://www.iana.org/assignments/hip-parameters/hip-parameters.xhtml#ecdsa-low-curve-label
+.. [*] https://www.iana.org/assignments/hip-parameters/hip-parameters.xhtml#eddsa-curve-label
 .. [*] https://www.iana.org/assignments/hip-parameters/hip-parameters.xhtml#esp-transform-suite-ids
 .. [*] https://www.iana.org/assignments/hip-parameters/hip-parameters.xhtml#hip-parameters-5
 .. [*] https://www.iana.org/assignments/hip-parameters/hip-parameters.xhtml#hi-algorithm
@@ -71,6 +74,7 @@ from pcapkit.const.hip.cipher import Cipher as HIP_Cipher
 from pcapkit.const.hip.di import DITypes as HIP_DITypes
 from pcapkit.const.hip.ecdsa_curve import ECDSACurve as HIP_ECDSACurve
 from pcapkit.const.hip.ecdsa_low_curve import ECDSALowCurve as HIP_ECDSALowCurve
+from pcapkit.const.hip.eddsa_curve import EdDSACurve as HIP_EdDSACurve
 from pcapkit.const.hip.esp_transform_suite import ESPTransformSuite as HIP_ESPTransformSuite
 from pcapkit.const.hip.group import Group as HIP_Group
 from pcapkit.const.hip.hi_algorithm import HIAlgorithm as HIP_HIAlgorithm
@@ -87,4 +91,4 @@ from pcapkit.const.hip.transport import Transport as HIP_Transport
 __all__ = ['HIP_Certificate', 'HIP_Cipher', 'HIP_DITypes', 'HIP_ECDSACurve', 'HIP_ECDSALowCurve',
            'HIP_ESPTransformSuite', 'HIP_Group', 'HIP_HIAlgorithm', 'HIP_HITSuite', 'HIP_NATTraversal',
            'HIP_NotifyMessage', 'HIP_Packet', 'HIP_Parameter', 'HIP_Registration', 'HIP_RegistrationFailure',
-           'HIP_Suite', 'HIP_Transport']
+           'HIP_Suite', 'HIP_Transport', 'HIP_EdDSACurve']
