@@ -3,9 +3,9 @@
 
 import copy
 import io
-from typing import TYPE_CHECKING, TypeVar, cast
+from typing import TYPE_CHECKING, Generic, TypeVar, cast
 
-from pcapkit.corekit.fields.field import _Field
+from pcapkit.corekit.fields.field import FieldBase
 from pcapkit.corekit.multidict import OrderedMultiDict
 from pcapkit.utilities.compat import List
 from pcapkit.utilities.exceptions import FieldValueError
@@ -24,10 +24,11 @@ if TYPE_CHECKING:
 
     from pcapkit.protocols.schema.schema import Schema
 
-_TL = TypeVar('_TL', 'Schema', '_Field', 'bytes')
+_TL = TypeVar('_TL', 'Schema', 'FieldBase', 'bytes')
+_TS = TypeVar('_TS', bound='Schema')
 
 
-class ListField(_Field[List[_TL]]):
+class ListField(FieldBase[List[_TL]], Generic[_TL]):
     """Field list for protocol fields.
 
     Args:
@@ -35,7 +36,7 @@ class ListField(_Field[List[_TL]]):
             an integer value and accept the current packet as its only argument.
         item_type: Field type of the contained items.
         callback: Callback function to be called upon
-            :meth:`self.__call__ <pcapkit.corekit.fields.field._Field.__call__>`.
+            :meth:`self.__call__ <pcapkit.corekit.fields.field.FieldBase.__call__>`.
 
     This field is used to represent a list of fields, as in the case of lists of
     constrant-length-field items in a protocol.
@@ -53,9 +54,9 @@ class ListField(_Field[List[_TL]]):
         return True
 
     def __init__(self, length: 'int | Callable[[dict[str, Any]], int]' = lambda _: -1,
-                 item_type: 'Optional[_Field]' = None,
+                 item_type: 'Optional[FieldBase]' = None,
                  callback: 'Callable[[Self, dict[str, Any]], None]' = lambda *_: None) -> 'None':
-        self._name = '<list>'
+        #self._name = '<list>'
         self._callback = callback
         self._item_type = item_type
 
@@ -74,9 +75,8 @@ class ListField(_Field[List[_TL]]):
         Returns:
             Updated field instance.
 
-        Notes:
-            This method will return a new instance of :class:`ListField`
-            instead of updating the current instance.
+        This method will return a new instance of :class:`ListField`
+        instead of updating the current instance.
 
         """
         new_self = copy.copy(self)
@@ -115,7 +115,7 @@ class ListField(_Field[List[_TL]]):
                 raise FieldValueError(f'Field {self.name} has invalid value.')
         return b''.join(temp)
 
-    def unpack(self, buffer: 'bytes | IO[bytes]', packet: 'dict[str, Any]') -> 'bytes | list[_TL]':  # type: ignore[override]
+    def unpack(self, buffer: 'bytes | IO[bytes]', packet: 'dict[str, Any]') -> 'bytes | list[_TL]':
         """Unpack field value from :obj:`bytes`.
 
         Args:
@@ -160,7 +160,7 @@ class ListField(_Field[List[_TL]]):
         return temp
 
 
-class OptionField(ListField):
+class OptionField(ListField, Generic[_TS]):
     """Field list for protocol options.
 
     Args:
@@ -173,7 +173,7 @@ class OptionField(ListField):
             option schema.
         eool: Enumeration of the EOOL (end-of-option-list, or equivalent) option
         callback: Callback function to be called upon
-            :meth:`self.__call__ <pcapkit.corekit.fields.field._Field.__call__>`.
+            :meth:`self.__call__ <pcapkit.corekit.fields.field.FieldBase.__call__>`.
 
     This field is used to represent a list of fields, as in the case of lists of
     options and/or parameters in a protocol.
@@ -181,7 +181,7 @@ class OptionField(ListField):
     """
 
     @property
-    def base_schema(self) -> 'Type[Schema]':
+    def base_schema(self) -> 'Type[_TS]':
         """Base schema."""
         return self._base_schema
 
@@ -191,7 +191,7 @@ class OptionField(ListField):
         return self._type_name
 
     @property
-    def registry(self) -> 'defaultdict[int | StdlibEnum | AenumEnum, Type[Schema]]':
+    def registry(self) -> 'defaultdict[int | StdlibEnum | AenumEnum, Type[_TS]]':
         """Option registry."""
         return self._registry
 
@@ -206,13 +206,13 @@ class OptionField(ListField):
         return self._option_padding
 
     def __init__(self, length: 'int | Callable[[dict[str, Any]], int]' = lambda _: -1,
-                 base_schema: 'Optional[Type[Schema]]' = None,
+                 base_schema: 'Optional[Type[_TS]]' = None,
                  type_name: 'str' = 'type',
-                 registry: 'Optional[defaultdict[int | StdlibEnum | AenumEnum, Type[Schema]]]' = None,
+                 registry: 'Optional[defaultdict[int | StdlibEnum | AenumEnum, Type[_TS]]]' = None,
                  eool: 'Optional[int | StdlibEnum | AenumEnum]' = None,
                  callback: 'Callable[[Self, dict[str, Any]], None]' = lambda *_: None) -> 'None':
         super().__init__(length, None, callback)
-        self._name = '<option>'
+        #self._name = '<option>'
         self._eool = eool
         self._option_padding = 0
 
@@ -228,7 +228,7 @@ class OptionField(ListField):
             raise FieldValueError('Field <option> has no registry.')
         self._registry = registry
 
-    def unpack(self, buffer: 'bytes | IO[bytes]', packet: 'dict[str, Any]') -> 'list[Schema]':
+    def unpack(self, buffer: 'bytes | IO[bytes]', packet: 'dict[str, Any]') -> 'list[_TS]':
         """Unpack field value from :obj:`bytes`.
 
         Args:
@@ -256,7 +256,7 @@ class OptionField(ListField):
         new_packet = packet.copy()
         new_packet[self.name] = OrderedMultiDict()
 
-        temp = []  # type: list[Schema]
+        temp = []  # type: list[_TS]
         while length > 0:
             # unpack option type using base schema
             meta = self._base_schema.unpack(file, length, packet)  # type: ignore[call-arg,misc,var-annotated]
