@@ -5,7 +5,7 @@ import copy
 import io
 from typing import TYPE_CHECKING, TypeVar, cast
 
-from pcapkit.corekit.fields.field import NoValue, _Field
+from pcapkit.corekit.fields.field import FieldBase, NoValue
 from pcapkit.utilities.exceptions import FieldError, NoDefaultValue
 
 __all__ = [
@@ -20,7 +20,7 @@ if TYPE_CHECKING:
     from typing_extensions import Self
 
     from pcapkit.corekit.fields.field import NoValueType
-    from pcapkit.protocols.protocol import Protocol
+    from pcapkit.protocols.protocol import ProtocolBase as Protocol
     from pcapkit.protocols.schema.schema import Schema
 
 _TC = TypeVar('_TC')
@@ -29,7 +29,7 @@ _TP = TypeVar('_TP', bound='Protocol')
 _TN = TypeVar('_TN', bound='NoValueType')
 
 
-class NoValueField(_Field[_TN]):
+class NoValueField(FieldBase[_TN]):
     """Schema field for no value type (or :obj:`None`)."""
 
     _default = NoValue
@@ -71,7 +71,7 @@ class NoValueField(_Field[_TN]):
         return None  # type: ignore[return-value]
 
 
-class ConditionalField(_Field[_TC]):
+class ConditionalField(FieldBase[_TC]):
     """Conditional value for protocol fields.
 
     Args:
@@ -123,13 +123,13 @@ class ConditionalField(_Field[_TC]):
         return True
 
     @property
-    def field(self) -> '_Field[_TC]':
+    def field(self) -> 'FieldBase[_TC]':
         """Field instance."""
         return self._field
 
-    def __init__(self, field: '_Field[_TC]',  # pylint: disable=super-init-not-called
+    def __init__(self, field: 'FieldBase[_TC]',  # pylint: disable=super-init-not-called
                  condition: 'Callable[[dict[str, Any]], bool]') -> 'None':
-        self._field = field  # type: _Field[_TC]
+        self._field = field  # type: FieldBase[_TC]
         self._condition = condition
 
     def __call__(self, packet: 'dict[str, Any]') -> 'Self':
@@ -141,9 +141,8 @@ class ConditionalField(_Field[_TC]):
         Returns:
             Updated field instance.
 
-        Notes:
-            This method will return a new instance of :class:`ConditionalField`
-            instead of updating the current instance.
+        This method will return a new instance of :class:`ConditionalField`
+        instead of updating the current instance.
 
         """
         new_self = copy.copy(self)
@@ -220,7 +219,7 @@ class ConditionalField(_Field[_TC]):
         return self._condition(packet)
 
 
-class PayloadField(_Field[_TP]):
+class PayloadField(FieldBase[_TP]):
     """Payload value for protocol fields.
 
     Args:
@@ -229,7 +228,7 @@ class PayloadField(_Field[_TP]):
         default: Field default value.
         protocol: Payload protocol.
         callback: Callback function to be called upon
-            :meth:`self.__call__ <pcapkit.corekit.fields.field._Field.__call__>`.
+            :meth:`self.__call__ <pcapkit.corekit.fields.field.FieldBase.__call__>`.
 
     """
 
@@ -273,7 +272,7 @@ class PayloadField(_Field[_TP]):
                  default: '_TP | NoValueType | bytes' = NoValue,
                  protocol: 'Optional[Type[_TP]]' = None,
                  callback: 'Callable[[Self, dict[str, Any]], None]' = lambda *_: None) -> 'None':
-        self._name = '<payload>'
+        #self._name = '<payload>'
         self._default = default  # type: ignore[assignment]
         self._protocol = protocol  # type: ignore[assignment]
         self._callback = callback
@@ -293,9 +292,8 @@ class PayloadField(_Field[_TP]):
         Returns:
             Updated field instance.
 
-        Notes:
-            This method will return a new instance of :class:`PayloadField`
-            instead of updating the current instance.
+        This method will return a new instance of :class:`PayloadField`
+        instead of updating the current instance.
 
         """
         new_self = copy.copy(self)
@@ -354,7 +352,7 @@ class PayloadField(_Field[_TP]):
         return self._protocol(file, length)  # type: ignore[abstract]
 
 
-class SwitchField(_Field[_TC]):
+class SwitchField(FieldBase[_TC]):
     """Conditional type-switching field for protocol schema.
 
     Args:
@@ -404,13 +402,13 @@ class SwitchField(_Field[_TC]):
         return True
 
     @property
-    def field(self) -> '_Field[_TC]':
+    def field(self) -> 'FieldBase[_TC]':
         """Field instance."""
         return self._field
 
-    def __init__(self, selector: 'Callable[[dict[str, Any]], _Field[_TC]]' = lambda _: NoValueField()) -> 'None':  # type: ignore[assignment,return-value]
-        self._name = '<switch>'
-        self._field = cast('_Field[_TC]', NoValueField())
+    def __init__(self, selector: 'Callable[[dict[str, Any]], FieldBase[_TC]]' = lambda _: NoValueField()) -> 'None':  # type: ignore[assignment,return-value]
+        #self._name = '<switch>'
+        self._field = cast('FieldBase[_TC]', NoValueField())
         self._selector = selector
 
     def __call__(self, packet: 'dict[str, Any]') -> 'SwitchField[_TC]':
@@ -422,9 +420,8 @@ class SwitchField(_Field[_TC]):
         Returns:
             New field instance.
 
-        Notes:
-            This method will return a new instance of :class:`SwitchField`
-            instead of updating the current instance.
+        This method will return a new instance of :class:`SwitchField`
+        instead of updating the current instance.
 
         """
         new_self = copy.copy(self)
@@ -493,7 +490,7 @@ class SwitchField(_Field[_TC]):
         return self._field.unpack(buffer, packet)
 
 
-class SchemaField(_Field[_TS]):
+class SchemaField(FieldBase[_TS]):
     """Schema field for protocol schema.
 
     Args:
@@ -527,7 +524,7 @@ class SchemaField(_Field[_TS]):
                  default: '_TS | NoValueType | bytes' = NoValue,
                  packet: 'Optional[dict[str, Any]]' = None,
                  callback: 'Callable[[Self, dict[str, Any]], None]' = lambda *_: None) -> 'None':
-        self._name = '<schema>'
+        #self._name = '<schema>'
         self._callback = callback
 
         if packet is None:
@@ -557,9 +554,8 @@ class SchemaField(_Field[_TS]):
         Returns:
             New field instance.
 
-        Notes:
-            This method will return a new instance of :class:`SchemaField`
-            instead of updating the current instance.
+        This method will return a new instance of :class:`SchemaField`
+        instead of updating the current instance.
 
         """
         new_self = copy.copy(self)
@@ -625,7 +621,7 @@ class SchemaField(_Field[_TS]):
         }))
 
 
-class ForwardMatchField(_Field[_TC]):
+class ForwardMatchField(FieldBase[_TC]):
     """Schema field for non-capturing forward matching.
 
     Args:
@@ -674,12 +670,12 @@ class ForwardMatchField(_Field[_TC]):
         return True
 
     @property
-    def field(self) -> '_Field[_TC]':
+    def field(self) -> 'FieldBase[_TC]':
         """Field instance."""
         return self._field
 
-    def __init__(self, field: '_Field[_TC]') -> 'None':
-        self._name = '<forward_match>'
+    def __init__(self, field: 'FieldBase[_TC]') -> 'None':
+        #self._name = '<forward_match>'
         self._field = field
 
     def __call__(self, packet: 'dict[str, Any]') -> 'Self':
@@ -691,9 +687,8 @@ class ForwardMatchField(_Field[_TC]):
         Returns:
             Updated field instance.
 
-        Notes:
-            This method will return a new instance of :class:`ConditionalField`
-            instead of updating the current instance.
+        This method will return a new instance of :class:`ConditionalField`
+        instead of updating the current instance.
 
         """
         new_self = copy.copy(self)
