@@ -20,13 +20,20 @@ if TYPE_CHECKING:
 
     from typing_extensions import Self
 
-    from pcapkit.protocols.protocol import Protocol
+    from pcapkit.protocols.protocol import ProtocolBase as Protocol
 
 __all__ = ['ProtoChain']
 
 
 class ProtoChain(collections.abc.Sequence):
-    """Protocols chain."""
+    """Protocols chain.
+
+    Args:
+        proto: New protocol class on the top stack.
+        alias: New protocol alias on the top stack.
+        basis: Original protocol chain as base stacks.
+
+    """
 
     #: Internal data storage for protocol chain.
     __data__: 'tuple[tuple[str, Type[Protocol]], ...]'
@@ -62,7 +69,8 @@ class ProtoChain(collections.abc.Sequence):
             data: Protocol chain list.
 
         """
-        from pcapkit.protocols.protocol import Protocol  # pylint: disable=import-outside-toplevel
+        from pcapkit.protocols.protocol import \
+            ProtocolBase as Protocol  # pylint: disable=import-outside-toplevel
 
         temp_data = []
         for proto in data:
@@ -98,7 +106,8 @@ class ProtoChain(collections.abc.Sequence):
             stop += len(self)
 
         # prepare comparison values
-        from pcapkit.protocols.protocol import Protocol  # pylint: disable=import-outside-toplevel
+        from pcapkit.protocols.protocol import \
+            ProtocolBase as Protocol  # pylint: disable=import-outside-toplevel
         comp = Protocol.expand_comp(value)
 
         pool = self.__data__[start:stop]
@@ -117,7 +126,8 @@ class ProtoChain(collections.abc.Sequence):
 
         """
         # prepare comparison values
-        from pcapkit.protocols.protocol import Protocol  # pylint: disable=import-outside-toplevel
+        from pcapkit.protocols.protocol import \
+            ProtocolBase as Protocol  # pylint: disable=import-outside-toplevel
         comp = Protocol.expand_comp(value)
 
         cnt = 0
@@ -143,7 +153,8 @@ class ProtoChain(collections.abc.Sequence):
             basis: Original protocol chain as base stacks.
 
         """
-        from pcapkit.protocols.protocol import Protocol  # pylint: disable=import-outside-toplevel
+        from pcapkit.protocols.protocol import \
+            ProtocolBase as Protocol  # pylint: disable=import-outside-toplevel
         if isinstance(proto, Protocol):
             if alias is None:
                 alias = proto.alias
@@ -189,7 +200,8 @@ class ProtoChain(collections.abc.Sequence):
             Whether ``name`` is in the chain.
 
         """
-        from pcapkit.protocols.protocol import Protocol  # pylint: disable=import-outside-toplevel
+        from pcapkit.protocols.protocol import \
+            ProtocolBase as Protocol  # pylint: disable=import-outside-toplevel
         comp = Protocol.expand_comp(name)
 
         for alias, proto in self.__data__:
