@@ -2,6 +2,8 @@
 """Null Dumper
 =================
 
+.. module:: pcapkit.dumper.null
+
 :mod:`pcapkit.dumpkit.null` is the dumper for :mod:`pcapkit` implementation,
 specifically for **NotImplemented** format, which is alike those described in
 :mod:`dictdumper`.
@@ -13,17 +15,17 @@ Notes:
 """
 from typing import TYPE_CHECKING
 
-import dictdumper
+from pcapkit.dumpkit.common import DumperBase as Dumper
 
 if TYPE_CHECKING:
-    from typing import Any, BinaryIO, Optional
+    from typing import IO, Any, Optional
 
     from typing_extensions import Literal
 
 __all__ = ['NotImplementedIO']
 
 
-class NotImplementedIO(dictdumper.Dumper):
+class NotImplementedIO(Dumper):
     """Unspecified output format."""
 
     ##########################################################################
@@ -64,7 +66,7 @@ class NotImplementedIO(dictdumper.Dumper):
 
         """
 
-    def _append_value(self, value: 'dict[str, Any]', file: 'BinaryIO', name: 'str') -> 'None':  # pylint: disable=unused-argument
+    def _append_value(self, value: 'dict[str, Any]', file: 'IO[bytes]', name: 'str') -> 'None':  # pylint: disable=unused-argument
         """Call this function to write contents.
 
         Args:
