@@ -10,7 +10,7 @@ support, as is used by :class:`pcapkit.foundation.extraction.Extractor`.
 """
 from typing import TYPE_CHECKING
 
-from pcapkit.foundation.engines.engine import Engine
+from pcapkit.foundation.engines.engine import EngineBase as Engine
 from pcapkit.protocols.misc.pcap.frame import Frame
 from pcapkit.protocols.misc.pcap.header import Header
 
@@ -47,18 +47,18 @@ class PCAP(Engine[Frame]):
     )
 
     ##########################################################################
-    # Properties.
+    # Defaults.
     ##########################################################################
 
-    @classmethod
-    def name(cls) -> 'str':
-        """Engine name."""
-        return 'PCAP'
+    #: Engine name.
+    __engine_name__ = 'PCAP'
 
-    @classmethod
-    def module(cls) -> 'str':
-        """Engine module name."""
-        return 'pcapkit.foundation.engine.pcap'
+    #: Engine module name.
+    __engine_module__ = 'pcapkit.protocols.misc.pcap'
+
+    ##########################################################################
+    # Properties.
+    ##########################################################################
 
     @property
     def header(self) -> 'Header':
@@ -75,6 +75,11 @@ class PCAP(Engine[Frame]):
         """Data link layer protocol."""
         return self._dlink
 
+    @property
+    def nanosecond(self) -> 'bool':
+        """Nanosecond flag."""
+        return self._nnsec
+
     ##########################################################################
     # Methods.
     ##########################################################################
@@ -84,11 +89,12 @@ class PCAP(Engine[Frame]):
 
         This method is the entry point for PCAP file extraction. It will start
         the extraction process by parsing the PCAP global header and then halt
-        the extraction process until the :meth:`self.extractor._read_frame <Extractor._read_frame>` method
-        is called.
+        the extraction process until the
+        :meth:`self.extractor.record_frames <pcapkit.foundation.extraction.Extractor.record_frames>`
+        method is called.
 
         The method will parse the PCAP global header and save the parsed result
-        as :attr:`self._gbhdr <_gbhdr>`. Information such as PCAP version, data
+        as :attr:`self.header <header>`. Information such as PCAP version, data
         link layer protocol type, nanosecond flag and byteorder will also be
         save the current :class:`PCAP` engine instance.
 
