@@ -3,9 +3,9 @@
 """Fragmented Packets Reassembly
 ===================================
 
-.. module:: pcapkit.reassembly
+.. module:: pcapkit.foundation.reassembly
 
-:mod:`pcapkit.reassembly` bases on algorithms described
+:mod:`pcapkit.foundation.reassembly` bases on algorithms described
 in :rfc:`791` and :rfc:`815`, implements datagram reassembly
 of IP and TCP packets.
 
