@@ -15,19 +15,19 @@ if TYPE_CHECKING:
     from ipaddress import IPv4Address, IPv6Address
     from typing import Optional, overload
 
-    from typing_extensions import Literal
+    from typing_extensions import Literal, TypeAlias
 
-    from pcapkit.protocols.protocol import Protocol
+    from pcapkit.protocols.protocol import ProtocolBase as Protocol
 
-IPAddress = TypeVar('IPAddress', 'IPv4Address', 'IPv6Address')
+_AT = TypeVar('_AT', 'IPv4Address', 'IPv6Address')
 
 #: Buffer ID.
-BufferID = Tuple[IPAddress, int, IPAddress, int]
+BufferID: 'TypeAlias' = Tuple[_AT, int, _AT, int]
 
 
 @info_final
 class Packet(Info):
-    """Data model for :term:`reasm.tcp.packet`."""
+    """Data model for :term:`TCP <reasm.tcp.packet>` packet representation."""
 
     #: Buffer ID.
     bufid: 'BufferID'
@@ -59,28 +59,28 @@ class Packet(Info):
 
 
 @info_final
-class DatagramID(Info, Generic[IPAddress]):
-    """Data model for :term:`reasm.tcp.datagram` original packet identifier."""
+class DatagramID(Info, Generic[_AT]):
+    """Data model for :term:`TCP <reasm.tcp.datagram>` original packet identifier."""
 
     #: Source address.
-    src: 'tuple[IPAddress, int]'
+    src: 'tuple[_AT, int]'
     #: Destination address.
-    dst: 'tuple[IPAddress, int]'
+    dst: 'tuple[_AT, int]'
     #: Original packet ACK number.
     ack: 'int'
 
     if TYPE_CHECKING:
-        def __init__(self, src: 'tuple[IPAddress, int]', dst: 'tuple[IPAddress, int]', ack: 'int') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
+        def __init__(self, src: 'tuple[_AT, int]', dst: 'tuple[_AT, int]', ack: 'int') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
 @info_final
-class Datagram(Info, Generic[IPAddress]):
-    """Data model for :term:`reasm.tcp.datagram`."""
+class Datagram(Info, Generic[_AT]):
+    """Data model for :term:`TCP <reasm.tcp.datagram>`."""
 
     #: Completed flag.
     completed: 'bool'
     #: Original packet identifier.
-    id: 'DatagramID[IPAddress]'
+    id: 'DatagramID[_AT]'
     #: Packet numbers.
     index: 'tuple[int, ...]'
     #: Initial TCP header.
@@ -92,17 +92,17 @@ class Datagram(Info, Generic[IPAddress]):
 
     if TYPE_CHECKING:
         @overload  # pylint: disable=used-before-assignment
-        def __init__(self, completed: 'Literal[True]', id: 'DatagramID[IPAddress]', index: 'tuple[int, ...]', header: 'bytes', payload: 'bytes', packet: 'Protocol') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
+        def __init__(self, completed: 'Literal[True]', id: 'DatagramID[_AT]', index: 'tuple[int, ...]', header: 'bytes', payload: 'bytes', packet: 'Protocol') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
         @overload
-        def __init__(self, completed: 'Literal[False]', id: 'DatagramID[IPAddress]', index: 'tuple[int, ...]', header: 'bytes', payload: 'tuple[bytes, ...]', packet: 'None') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
+        def __init__(self, completed: 'Literal[False]', id: 'DatagramID[_AT]', index: 'tuple[int, ...]', header: 'bytes', payload: 'tuple[bytes, ...]', packet: 'None') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
-        def __init__(self, completed: 'bool', id: 'DatagramID[IPAddress]', index: 'tuple[int, ...]', header: 'bytes', payload: 'bytes | tuple[bytes, ...]', packet: 'Optional[Protocol]') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
+        def __init__(self, completed: 'bool', id: 'DatagramID[_AT]', index: 'tuple[int, ...]', header: 'bytes', payload: 'bytes | tuple[bytes, ...]', packet: 'Optional[Protocol]') -> 'None': ...  # pylint: disable=unused-argument,super-init-not-called,multiple-statements,line-too-long,redefined-builtin
 
 
 @info_final
 class HoleDiscriptor(Info):
-    """Data model for :term:`reasm.tcp.buffer` hole descriptor."""
+    """Data model for :term:`TCP <reasm.tcp.buffer>` hole descriptor."""
 
     #: Start of hole.
     first: 'int'
@@ -115,7 +115,7 @@ class HoleDiscriptor(Info):
 
 @info_final
 class Fragment(Info):
-    """Data model for :term:`reasm.tcp.buffer` ACK list fragment item."""
+    """Data model for :term:`TCP <reasm.tcp.buffer>` ACK list fragment item."""
 
     #: List of reassembled packets.
     ind: 'list[int]'
@@ -132,7 +132,7 @@ class Fragment(Info):
 
 @info_final
 class Buffer(Info):
-    """Data model for :term:`reasm.tcp.buffer`."""
+    """Data model for :term:`TCP <reasm.tcp.buffer>` buffer entry."""
 
     #: Hole descriptor list.
     hdl: 'list[HoleDiscriptor]'
