@@ -3,6 +3,8 @@
 """Protocol Family
 =====================
 
+.. module:: pcapkit.protocols
+
 :mod:`pcapkit.protocols` is collection of all protocol families,
 with detailed implementation and methods.
 
@@ -21,13 +23,26 @@ from pcapkit.protocols.internet import *
 from pcapkit.protocols.transport import *
 from pcapkit.protocols.application import *
 
+# Protocol Data
+from pcapkit.protocols import data
+from pcapkit.protocols.data.data import Data
+
+# Protocol Schema
+from pcapkit.protocols import schema
+from pcapkit.protocols.schema.schema import Schema
+
 if TYPE_CHECKING:
     from typing import Type
 
+    from pcapkit.protocols.protocol import ProtocolBase
+
 __all__ = [
     # PCAP Headers
     'Header', 'Frame',
 
+    # PCAPNG Format
+    'PCAPNG',
+
     # No Payload
     'NoPayload',
 
@@ -49,15 +64,22 @@ __all__ = [
     'TCP', 'UDP',
 
     # Application Layer
-    'FTP', 'HTTP', 'HTTPv1', 'HTTPv2',
+    'FTP', 'FTP_DATA',
+    'HTTP', 'HTTPv1', 'HTTPv2',
 ]
 
-# protocol registry
-__proto__ = {}  # type: dict[str, Type[Protocol]]
+#: dict[str, Type[Protocol]]: Protocol registry.
+__proto__ = {}  # type: dict[str, Type[ProtocolBase]]
 for name in __all__:
     __proto__[name.upper()] = globals()[name]
 
 __all__.extend((
     # Protocol Numbers
-    'LINKTYPE', 'ETHERTYPE', 'TRANSTYPE',
+    'LINKTYPE', 'ETHERTYPE', 'TRANSTYPE', 'APPTYPE',
+
+    # Protocol Data
+    'Data', 'data',
+
+    # Protocol Schema
+    'Schema', 'schema',
 ))
