@@ -4,7 +4,7 @@
 from typing import TYPE_CHECKING
 
 from pcapkit.corekit.infoclass import info_final
-from pcapkit.protocols.data.data import Data
+from pcapkit.protocols.data.protocol import Protocol
 
 if TYPE_CHECKING:
     from ipaddress import IPv6Address
@@ -19,7 +19,7 @@ __all__ = [
 ]
 
 
-class IPv6_Route(Data):
+class IPv6_Route(Protocol):
     """Data model for IPv6-Route protocol."""
 
     #: Next header.
