@@ -5,6 +5,7 @@ from typing import TYPE_CHECKING
 
 from pcapkit.corekit.infoclass import info_final
 from pcapkit.protocols.data.data import Data
+from pcapkit.protocols.data.protocol import Protocol
 
 if TYPE_CHECKING:
     from pcapkit.const.ipx.packet import Packet
@@ -35,7 +36,7 @@ class Address(Data):
 
 
 @info_final
-class IPX(Data):
+class IPX(Protocol):
     """Data model for Internetwork Packet Exchange."""
 
     #: Checksum.
