@@ -48,14 +48,12 @@ from pcapkit.utilities.warnings import RegistryWarning, warn
 if TYPE_CHECKING:
     from enum import IntEnum as StdlibEnum
     from ipaddress import IPv6Address
-    from typing import IO, Any, Callable, DefaultDict, NoReturn, Optional, Type
+    from typing import IO, Any, Callable, DefaultDict, Optional, Type
 
     from aenum import IntEnum as AenumEnum
     from mypy_extensions import DefaultArg, KwArg, NamedArg
     from typing_extensions import Literal
 
-    from pcapkit.corekit.protochain import ProtoChain
-    from pcapkit.protocols.protocol import ProtocolBase as Protocol
     from pcapkit.protocols.schema.internet.ipv6_route import RoutingType as Schema_RoutingType
 
     TypeParser = Callable[[Schema_RoutingType, NamedArg(Schema_IPv6_Route, 'header')], Data_IPv6_Route]
@@ -402,7 +400,7 @@ class IPv6_Route(Internet[Data_IPv6_Route, Schema_IPv6_Route],
         """
         ipv6_route = Data_UnknownType(
             next=header.next,
-            length=header.length,
+            length=header.length * 8 + 8,
             type=header.type,
             seg_left=header.seg_left,
             data=schema.data,
@@ -463,7 +461,7 @@ class IPv6_Route(Internet[Data_IPv6_Route, Schema_IPv6_Route],
 
         ipv6_route = Data_SourceRoute(
             next=header.next,
-            length=header.length,
+            length=header.length * 8 + 8,
             type=header.type,
             seg_left=header.seg_left,
             ip=tuple(schema.ip),
@@ -507,7 +505,7 @@ class IPv6_Route(Internet[Data_IPv6_Route, Schema_IPv6_Route],
 
         ipv6_route = Data_Type2(
             next=header.next,
-            length=header.length,
+            length=header.length * 8 + 8,
             type=header.type,
             seg_left=header.seg_left,
             ip=schema.ip,
@@ -547,7 +545,7 @@ class IPv6_Route(Internet[Data_IPv6_Route, Schema_IPv6_Route],
 
         ipv6_route = Data_RPL(
             next=header.next,
-            length=header.length,
+            length=header.length * 8 + 8,
             type=header.type,
             seg_left=header.seg_left,
             cmpr_i=schema.cmpr_i,
