@@ -2,6 +2,8 @@
 """RARP/DRARP - (Dynamic) Reverse Address Resolution Protocol
 ================================================================
 
+.. module:: pcapkit.protocols.link.rarp
+
 :mod:`pcapkit.protocols.link.rarp` contains
 :class:`~pcapkit.protocols.link.rarp.RARP` only,
 which implements extractor for (Dynamic) Reverse
@@ -27,16 +29,18 @@ Octets      Bits        Name                    Description
 """
 from typing import TYPE_CHECKING
 
-from pcapkit.const.reg.ethertype import EtherType as RegType_EtherType
+from pcapkit.const.reg.ethertype import EtherType as Enum_EtherType
+from pcapkit.protocols.data.link.arp import ARP as Data_ARP
 from pcapkit.protocols.link.arp import ARP
+from pcapkit.protocols.schema.link.arp import ARP as Schema_ARP
 
 if TYPE_CHECKING:
     from typing_extensions import Literal
 
-__all__ = ['RARP']
+__all__ = ['RARP', 'DRARP']
 
 
-class RARP(ARP):  # pylint: disable=abstract-method
+class RARP(ARP, schema=Schema_ARP, data=Data_ARP):  # pylint: disable=abstract-method
     """This class implements Reverse Address Resolution Protocol."""
 
     ##########################################################################
@@ -53,7 +57,7 @@ class RARP(ARP):  # pylint: disable=abstract-method
     ##########################################################################
 
     @classmethod
-    def __index__(cls) -> 'RegType_EtherType':  # pylint: disable=invalid-index-returned
+    def __index__(cls) -> 'Enum_EtherType':  # pylint: disable=invalid-index-returned
         """Numeral registry index of the protocol.
 
         Returns:
@@ -62,4 +66,17 @@ class RARP(ARP):  # pylint: disable=abstract-method
         .. _IANA: https://www.iana.org/assignments/ieee-802-numbers/ieee-802-numbers.xhtml
 
         """
-        return RegType_EtherType.Reverse_Address_Resolution_Protocol  # type: ignore[return-value]
+        return Enum_EtherType.Reverse_Address_Resolution_Protocol  # type: ignore[return-value]
+
+
+class DRARP(RARP):
+    """This class implements Dynamic Reverse Address Resolution Protocol."""
+
+    ##########################################################################
+    # Methods.
+    ##########################################################################
+
+    @classmethod
+    def id(cls) -> 'tuple[Literal["DRARP"]]':  # type: ignore[override]
+        """Index ID of the protocol."""
+        return ('DRARP',)
