@@ -18,8 +18,8 @@ if TYPE_CHECKING:
     from ipaddress import IPv4Address
     from typing import Any
 
-    from pcapkit.corekit.fields.field import _Field as Field
-    from pcapkit.protocols.protocol import Protocol
+    from pcapkit.corekit.fields.field import FieldBase as Field
+    from pcapkit.protocols.protocol import ProtocolBase as Protocol
 
 
 def ospf_auth_data_selector(pkt: 'dict[str, Any]') -> 'Field':
