@@ -10,7 +10,7 @@ from pcapkit.protocols.schema.schema import Schema, schema_final
 __all__ = ['Raw']
 
 if TYPE_CHECKING:
-    from pcapkit.protocols.protocol import Protocol
+    from pcapkit.protocols.protocol import ProtocolBase as Protocol
 
 
 @schema_final
