@@ -3,8 +3,10 @@
 """header schema for transmission control protocol"""
 
 import collections
-from typing import TYPE_CHECKING, cast
+from typing import TYPE_CHECKING
 
+from pcapkit.const.reg.apptype import AppType as Enum_AppType
+from pcapkit.const.reg.apptype import TransportProtocol as Enum_TransportProtocol
 from pcapkit.const.tcp.checksum import Checksum as Enum_Checksum
 from pcapkit.const.tcp.mp_tcp_option import MPTCPOption as Enum_MPTCPOption
 from pcapkit.const.tcp.option import Option as Enum_Option
@@ -15,7 +17,7 @@ from pcapkit.corekit.fields.misc import (ConditionalField, ForwardMatchField, Pa
 from pcapkit.corekit.fields.numbers import (EnumField, NumberField, UInt8Field, UInt16Field,
                                             UInt32Field, UInt64Field)
 from pcapkit.corekit.fields.strings import BitField, BytesField, PaddingField
-from pcapkit.protocols.schema.schema import Schema, schema_final
+from pcapkit.protocols.schema.schema import EnumSchema, Schema, schema_final
 from pcapkit.utilities.exceptions import FieldError
 from pcapkit.utilities.logging import SPHINX_TYPE_CHECKING
 
@@ -24,8 +26,8 @@ __all__ = [
 
     'Option',
     'UnassignedOption', 'EndOfOptionList', 'NoOperation', 'MaximumSegmentSize', 'WindowScale',
-    'SACKPermitted', 'SACK', 'Echo', 'EchoReply', 'Timestamp', 'PartialOrderConnectionPermitted',
-    'PartialOrderConnectionProfile', 'CC', 'CCNew', 'CCEcho', 'AlternateChecksumRequest',
+    'SACKPermitted', 'SACK', 'Echo', 'EchoReply', 'Timestamps', 'PartialOrderConnectionPermitted',
+    'PartialOrderServiceProfile', 'CC', 'CCNew', 'CCEcho', 'AlternateChecksumRequest',
     'AlternateChecksumData', 'MD5Signature', 'QuickStartResponse', 'UserTimeout',
     'Authentication', 'FastOpenCookie',
 
@@ -39,10 +41,10 @@ __all__ = [
 
 if TYPE_CHECKING:
     from ipaddress import IPv4Address, IPv6Address
-    from typing import Any, Optional
+    from typing import Any, DefaultDict, Optional, Type
 
-    from pcapkit.corekit.fields.field import _Field as Field
-    from pcapkit.protocols.protocol import Protocol
+    from pcapkit.corekit.fields.field import FieldBase as Field
+    from pcapkit.protocols.protocol import ProtocolBase as Protocol
 
 if SPHINX_TYPE_CHECKING:
     from typing_extensions import TypedDict
@@ -197,30 +199,18 @@ def mptcp_data_selector(pkt: 'dict[str, Any]') -> 'Field':
     """
     subtype = Enum_MPTCPOption.get(pkt['test']['subtype'])
     pkt['test']['subtype'] = subtype
+    schema = MPTCP.registry[subtype]
 
-    if subtype == Enum_MPTCPOption.MP_CAPABLE:
-        return SchemaField(length=pkt['test']['length'], schema=MPTCPCapable)
-    if subtype == Enum_MPTCPOption.MP_JOIN:
+    if subtype == Enum_MPTCPOption.MP_JOIN and schema is MPTCPJoin:  # placeholder
         if pkt['flags']['syn'] == 1 and pkt['flags']['ack'] == 0:
-            return SchemaField(length=pkt['test']['length'], schema=MPTCPJoinSYN)
-        if pkt['flags']['syn'] == 1 and pkt['flags']['ack'] == 1:
-            return SchemaField(length=pkt['test']['length'], schema=MPTCPJoinSYNACK)
-        if pkt['flags']['syn'] == 0 and pkt['flags']['ack'] == 1:
-            return SchemaField(length=pkt['test']['length'], schema=MPTCPJoinACK)
-        raise FieldError(f'TCP: [OptNo {Enum_Option.Multipath_TCP}] {Enum_MPTCPOption.MP_JOIN} invalid flags')
-    if subtype == Enum_MPTCPOption.DSS:
-        return SchemaField(length=pkt['test']['length'], schema=MPTCPDSS)
-    if subtype == Enum_MPTCPOption.ADD_ADDR:
-        return SchemaField(length=pkt['test']['length'], schema=MPTCPAddAddress)
-    if subtype == Enum_MPTCPOption.REMOVE_ADDR:
-        return SchemaField(length=pkt['test']['length'], schema=MPTCPRemoveAddress)
-    if subtype == Enum_MPTCPOption.MP_PRIO:
-        return SchemaField(length=pkt['test']['length'], schema=MPTCPPriority)
-    if subtype == Enum_MPTCPOption.MP_FAIL:
-        return SchemaField(length=pkt['test']['length'], schema=MPTCPFallback)
-    if subtype == Enum_MPTCPOption.MP_FASTCLOSE:
-        return SchemaField(length=pkt['test']['length'], schema=MPTCPFastclose)
-    return SchemaField(length=pkt['test']['length'], schema=MPTCPUnknown)
+            schema = MPTCPJoinSYN
+        elif pkt['flags']['syn'] == 1 and pkt['flags']['ack'] == 1:
+            schema = MPTCPJoinSYNACK
+        elif pkt['flags']['syn'] == 0 and pkt['flags']['ack'] == 1:
+            schema = MPTCPJoinACK
+        else:
+            raise FieldError(f'TCP: [OptNo {Enum_Option.Multipath_TCP}] {Enum_MPTCPOption.MP_JOIN} invalid flags')
+    return SchemaField(length=pkt['test']['length'], schema=schema)
 
 
 def mptcp_add_address_selector(pkt: 'dict[str, Any]') -> 'Field':
@@ -230,9 +220,9 @@ def mptcp_add_address_selector(pkt: 'dict[str, Any]') -> 'Field':
         pkt: Packet data.
 
     Returns:
-        * If IP version is 4, a :class:`~pcapkit.corekit.fields.ipaddress.IPv4Field`
+        * If IP version is 4, a :class:`~pcapkit.corekit.fields.ipaddress.IPv4AddressField`
           instance.
-        * If IP version is 6, a :class:`~pcapkit.corekit.fields.ipaddress.IPv6Field`
+        * If IP version is 6, a :class:`~pcapkit.corekit.fields.ipaddress.IPv6AddressField`
           instance.
 
     """
@@ -243,9 +233,62 @@ def mptcp_add_address_selector(pkt: 'dict[str, Any]') -> 'Field':
     raise FieldError(f'TCP: [OptNo {Enum_Option.Multipath_TCP}] {Enum_MPTCPOption.ADD_ADDR} invalid IP version')
 
 
-class Option(Schema):
+class PortEnumField(EnumField):
+    """Enumerated value for protocol fields.
+
+    Args:
+        length: Field size (in bytes); if a callable is given, it should return
+            an integer value and accept the current packet as its only argument.
+        default: Field default value, if any.
+        signed: Whether the field is signed.
+        byteorder: Field byte order.
+        bit_length: Field bit length.
+        callback: Callback function to be called upon
+            :meth:`self.__call__ <pcapkit.corekit.fields.field.FieldBase.__call__>`.
+
+    Important:
+        This class is specifically designed for :class:`~pcapkit.const.reg.apptype.AppType`
+        as it is actually a :class:`~enum.StrEnum` class.
+
+    """
+    if TYPE_CHECKING:
+        _namespace: 'Enum_AppType'
+
+    def pre_process(self, value: 'int | Enum_AppType', packet: 'dict[str, Any]') -> 'int | bytes':
+        """Process field value before construction (packing).
+
+        Arguments:
+            value: Field value.
+            packet: Packet data.
+
+        Returns:
+            Processed field value.
+
+        """
+        if isinstance(value, Enum_AppType):
+            value = value.port
+        return super().pre_process(value, packet)
+
+    def post_process(self, value: 'int | bytes', packet: 'dict[str, Any]') -> 'Enum_AppType':
+        """Process field value after parsing (unpacked).
+
+        Args:
+            value: Field value.
+            packet: Packet data.
+
+        Returns:
+            Processed field value.
+
+        """
+        value = super(EnumField, self).post_process(value, packet)
+        return self._namespace.get(value, proto=Enum_TransportProtocol.tcp)
+
+
+class Option(EnumSchema[Enum_Option]):
     """Header schema for TCP options."""
 
+    __default__ = lambda: UnassignedOption
+
     #: Option kind.
     kind: 'Enum_Option' = EnumField(length=1, namespace=Enum_Option)
     #: Option length.
@@ -282,7 +325,7 @@ class UnassignedOption(Option):
 
 
 @schema_final
-class EndOfOptionList(Option):
+class EndOfOptionList(Option, code=Enum_Option.End_of_Option_List):
     """Header schema for TCP end of option list."""
 
     if TYPE_CHECKING:
@@ -290,7 +333,7 @@ class EndOfOptionList(Option):
 
 
 @schema_final
-class NoOperation(Option):
+class NoOperation(Option, code=Enum_Option.No_Operation):
     """Header schema for TCP no operation."""
 
     if TYPE_CHECKING:
@@ -298,7 +341,7 @@ class NoOperation(Option):
 
 
 @schema_final
-class MaximumSegmentSize(Option):
+class MaximumSegmentSize(Option, code=Enum_Option.Maximum_Segment_Size):
     """Header schema for TCP max segment size option."""
 
     #: Maximum segment size.
@@ -309,7 +352,7 @@ class MaximumSegmentSize(Option):
 
 
 @schema_final
-class WindowScale(Option):
+class WindowScale(Option, code=Enum_Option.Window_Scale):
     """Header schema for TCP window scale option."""
 
     #: Window scale (shift count).
@@ -320,7 +363,7 @@ class WindowScale(Option):
 
 
 @schema_final
-class SACKPermitted(Option):
+class SACKPermitted(Option, code=Enum_Option.SACK_Permitted):
     """Header schema for TCP SACK permitted option."""
 
     if TYPE_CHECKING:
@@ -341,7 +384,7 @@ class SACKBlock(Schema):
 
 
 @schema_final
-class SACK(Option):
+class SACK(Option, code=Enum_Option.SACK):
     """Header schema for TCP SACK option."""
 
     #: Selected ACK data.
@@ -355,7 +398,7 @@ class SACK(Option):
 
 
 @schema_final
-class Echo(Option):
+class Echo(Option, code=Enum_Option.Echo):
     """Header schema for TCP echo option."""
 
     #: Info to be echoed.
@@ -366,7 +409,7 @@ class Echo(Option):
 
 
 @schema_final
-class EchoReply(Option):
+class EchoReply(Option, code=Enum_Option.Echo_Reply):
     """Header schema for TCP echo reply option."""
 
     #: Echoed info.
@@ -377,7 +420,7 @@ class EchoReply(Option):
 
 
 @schema_final
-class Timestamp(Option):
+class Timestamps(Option, code=Enum_Option.Timestamps):
     """Header schema for TCP timestamps option."""
 
     #: Timestamp value.
@@ -390,7 +433,7 @@ class Timestamp(Option):
 
 
 @schema_final
-class PartialOrderConnectionPermitted(Option):
+class PartialOrderConnectionPermitted(Option, code=Enum_Option.Partial_Order_Connection_Permitted):
     """Header schema for TCP partial order connection permitted option."""
 
     if TYPE_CHECKING:
@@ -398,7 +441,7 @@ class PartialOrderConnectionPermitted(Option):
 
 
 @schema_final
-class PartialOrderConnectionProfile(Option):
+class PartialOrderServiceProfile(Option, code=Enum_Option.Partial_Order_Service_Profile):
     """Header schema for TCP partial order connection service profile option."""
 
     #: Profile data.
@@ -412,7 +455,7 @@ class PartialOrderConnectionProfile(Option):
 
 
 @schema_final
-class CC(Option):
+class CC(Option, code=Enum_Option.CC):
     """Header schema for TCP CC option."""
 
     #: Connection count.
@@ -423,7 +466,7 @@ class CC(Option):
 
 
 @schema_final
-class CCNew(Option):
+class CCNew(Option, code=Enum_Option.CC_NEW):
     """Header schema for TCP connection count (new) option."""
 
     #: Connection count.
@@ -434,7 +477,7 @@ class CCNew(Option):
 
 
 @schema_final
-class CCEcho(Option):
+class CCEcho(Option, code=Enum_Option.CC_ECHO):
     """Header schema for TCP connection count (echo) option."""
 
     #: Connection count.
@@ -445,7 +488,7 @@ class CCEcho(Option):
 
 
 @schema_final
-class AlternateChecksumRequest(Option):
+class AlternateChecksumRequest(Option, code=Enum_Option.TCP_Alternate_Checksum_Request):
     """Header schema for TCP alternate checksum request option."""
 
     #: Checksum algorithm.
@@ -456,7 +499,7 @@ class AlternateChecksumRequest(Option):
 
 
 @schema_final
-class AlternateChecksumData(Option):
+class AlternateChecksumData(Option, code=Enum_Option.TCP_Alternate_Checksum_Data):
     """Header schema for TCP alternate checksum data option."""
 
     #: Checksum data.
@@ -467,7 +510,7 @@ class AlternateChecksumData(Option):
 
 
 @schema_final
-class MD5Signature(Option):
+class MD5Signature(Option, code=Enum_Option.MD5_Signature_Option):
     """Header schema for TCP MD5 signature option."""
 
     #: MD5 digest.
@@ -478,7 +521,7 @@ class MD5Signature(Option):
 
 
 @schema_final
-class QuickStartResponse(Option):
+class QuickStartResponse(Option, code=Enum_Option.Quick_Start_Response):
     """Header schema for TCP quick start response option."""
 
     #: Flags.
@@ -497,7 +540,7 @@ class QuickStartResponse(Option):
 
 
 @schema_final
-class UserTimeout(Option):
+class UserTimeout(Option, code=Enum_Option.User_Timeout_Option):
     """Header schema for TCP user timeout option."""
 
     #: Granularity and user timeout.
@@ -511,7 +554,7 @@ class UserTimeout(Option):
 
 
 @schema_final
-class Authentication(Option):
+class Authentication(Option, code=Enum_Option.TCP_Authentication_Option):
     """Header schema for TCP authentication option."""
 
     #: Key ID.
@@ -550,14 +593,28 @@ class _MPTCP(Schema):
 
         """
         ret = self.data
+
+        ret.option = Enum_Option.Multipath_TCP
+        ret.length = self.test['length']
         ret.subtype = Enum_MPTCPOption.get(packet['test']['subtype'])
+
         return ret
 
 
-class MPTCP(Option):
+# register ``_MPTCP`` as ``Multipath_TCP`` option
+Option.register(Enum_Option.Multipath_TCP, _MPTCP)
+
+
+class MPTCP(EnumSchema[Enum_MPTCPOption]):
     """Header schema for Multipath TCP options."""
 
+    __enum__: 'DefaultDict[Enum_MPTCPOption, Type[MPTCP]]' = collections.defaultdict(lambda: MPTCPUnknown)
+
     if TYPE_CHECKING:
+        #: Option kind.
+        kind: 'Enum_Option'
+        #: MPTCP length.
+        length: 'int'
         #: MPTCP subtype.
         subtype: 'Enum_MPTCPOption'
 
@@ -579,7 +636,7 @@ class MPTCPUnknown(MPTCP):
 
 
 @schema_final
-class MPTCPCapable(MPTCP):
+class MPTCPCapable(MPTCP, code=Enum_MPTCPOption.MP_CAPABLE):
     """Header schema for Multipath TCP capable option."""
 
     #: Subtype and version.
@@ -605,7 +662,7 @@ class MPTCPCapable(MPTCP):
         def __init__(self, kind: 'Enum_Option', length: 'int', test: 'MPTCPSubtypeCapable', flags: 'MPTCPCapableFlags', skey: 'int', rkey: 'Optional[int]') -> 'None': ...
 
 
-class MPTCPJoin(MPTCP):
+class MPTCPJoin(MPTCP, code=Enum_MPTCPOption.MP_JOIN):  # register as a placeholder
     """Header schema for Multipath TCP join option."""
 
 
@@ -667,7 +724,7 @@ class MPTCPJoinACK(MPTCPJoin):
 
 
 @schema_final
-class MPTCPDSS(MPTCP):
+class MPTCPDSS(MPTCP, code=Enum_MPTCPOption.DSS):
     """Header schema for Multipath TCP DSS option."""
 
     #: Subtype and flags.
@@ -713,7 +770,7 @@ class MPTCPDSS(MPTCP):
 
 
 @schema_final
-class MPTCPAddAddress(MPTCP):
+class MPTCPAddAddress(MPTCP, code=Enum_MPTCPOption.ADD_ADDR):
     """Header schema for Multipath TCP add address option."""
 
     #: Subtype and IP version.
@@ -738,7 +795,7 @@ class MPTCPAddAddress(MPTCP):
 
 
 @schema_final
-class MPTCPRemoveAddress(MPTCP):
+class MPTCPRemoveAddress(MPTCP, code=Enum_MPTCPOption.REMOVE_ADDR):
     """Header schema for Multipath TCP remove address option."""
 
     #: Subtype.
@@ -756,7 +813,7 @@ class MPTCPRemoveAddress(MPTCP):
 
 
 @schema_final
-class MPTCPPriority(MPTCP):
+class MPTCPPriority(MPTCP, code=Enum_MPTCPOption.MP_PRIO):
     """Header schema for Multipath TCP priority option."""
 
     #: Subtype.
@@ -775,7 +832,7 @@ class MPTCPPriority(MPTCP):
 
 
 @schema_final
-class MPTCPFallback(MPTCP):
+class MPTCPFallback(MPTCP, code=Enum_MPTCPOption.MP_FAIL):
     """Header schema for Multipath TCP fallback option."""
 
     #: Subtype.
@@ -790,7 +847,7 @@ class MPTCPFallback(MPTCP):
 
 
 @schema_final
-class MPTCPFastclose(MPTCP):
+class MPTCPFastclose(MPTCP, code=Enum_MPTCPOption.MP_FASTCLOSE):
     """Header schema for Multipath TCP fastclose option."""
 
     #: Subtype.
@@ -805,7 +862,7 @@ class MPTCPFastclose(MPTCP):
 
 
 @schema_final
-class FastOpenCookie(Option):
+class FastOpenCookie(Option, code=Enum_Option.TCP_Fast_Open_Cookie):
     """"Header schema for TCP Fast Open option."""
 
     #: Cookie.
@@ -823,9 +880,9 @@ class TCP(Schema):
     """Header schema for TCP packet."""
 
     #: Source port.
-    srcport: 'int' = UInt16Field()
+    srcport: 'Enum_AppType' = PortEnumField(length=2, namespace=Enum_AppType)
     #: Destination port.
-    dstport: 'int' = UInt16Field()
+    dstport: 'Enum_AppType' = PortEnumField(length=2, namespace=Enum_AppType)
     #: Sequence number.
     seq: 'int' = UInt32Field()
     #: Acknowledgement number.
@@ -857,31 +914,8 @@ class TCP(Schema):
         length=lambda pkt: pkt['offset']['offset'] * 4 - 20,
         base_schema=Option,
         type_name='kind',
+        registry=Option.registry,
         eool=Enum_Option.End_of_Option_List,
-        registry=collections.defaultdict(lambda: UnassignedOption, {
-            Enum_Option.End_of_Option_List: EndOfOptionList,
-            Enum_Option.No_Operation: NoOperation,
-            Enum_Option.Maximum_Segment_Size: MaximumSegmentSize,
-            Enum_Option.Window_Scale: WindowScale,
-            Enum_Option.SACK_Permitted: SACKPermitted,
-            Enum_Option.SACK: SACK,
-            Enum_Option.Echo: Echo,
-            Enum_Option.Echo_Reply: EchoReply,
-            Enum_Option.Timestamps: Timestamp,
-            Enum_Option.Partial_Order_Connection_Permitted: PartialOrderConnectionPermitted,
-            Enum_Option.Partial_Order_Service_Profile: PartialOrderConnectionProfile,
-            Enum_Option.CC: CC,
-            Enum_Option.CC_NEW: CCNew,
-            Enum_Option.CC_ECHO: CCEcho,
-            Enum_Option.TCP_Alternate_Checksum_Request: AlternateChecksumRequest,
-            Enum_Option.TCP_Alternate_Checksum_Data: AlternateChecksumData,
-            Enum_Option.MD5_Signature_Option: MD5Signature,
-            Enum_Option.Quick_Start_Response: QuickStartResponse,
-            Enum_Option.User_Timeout_Option: UserTimeout,
-            Enum_Option.TCP_Authentication_Option: Authentication,
-            Enum_Option.Multipath_TCP: _MPTCP,
-            Enum_Option.TCP_Fast_Open_Cookie: FastOpenCookie,
-        }),
     )
     #: Padding.
     padding: 'bytes' = PaddingField(length=lambda pkt: pkt.get('__option_padding__', 0))  # key generated by OptionField
@@ -889,6 +923,6 @@ class TCP(Schema):
     payload: 'bytes' = PayloadField()
 
     if TYPE_CHECKING:
-        def __init__(self, srcport: 'int', dstport: 'int', seq: 'int', ack: 'int',
+        def __init__(self, srcport: 'Enum_AppType | int', dstport: 'Enum_AppType | int', seq: 'int', ack: 'int',
                      offset: 'OffsetFlag', flags: 'Flags', window: 'int', checksum: 'bytes',
                      urgent: 'int', options: 'list[Option | bytes] | bytes', payload: 'bytes | Protocol | Schema') -> 'None': ...
